import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';

import 'support/test_helper.dart';

import 'package:easy_image_viewer/easy_image_view.dart';

void main() {

  group('EasyImageView', () {
    testWidgets('should have an image and a scale', (WidgetTester tester) async {
      ImageProvider? imageProvider;
      
      await tester.runAsync(() async {
        imageProvider = await createColorImage(Colors.green);
      });
      
      Widget testWidget = MediaQuery(
        data: const MediaQueryData(size: Size(600, 800)),
        child: EasyImageView(imageProvider: imageProvider!, minScale: 0.5, maxScale: 6.0)
      );

      await tester.pumpWidget(testWidget);

      // Create the Finders.
      final sizedBoxFinder = find.byKey(const Key('easy_image_sized_box'));
      final interactiveViewFinder = find.byKey(const Key('easy_image_interactive_viewer'));
      final imageFinder = find.image(imageProvider!);

      // Check existence
      expect(sizedBoxFinder, findsOneWidget);
      expect(interactiveViewFinder, findsOneWidget);
      expect(imageFinder, findsOneWidget);

      // Check properties
      SizedBox sizedBox = tester.firstWidget(sizedBoxFinder);
      expect(sizedBox.width, 600);
      expect(sizedBox.height, 800);
      InteractiveViewer interactiveViewer = tester.firstWidget(interactiveViewFinder);
      expect(interactiveViewer.minScale, 0.5);
      expect(interactiveViewer.maxScale, 6.0);
    });

    testWidgets('should invoke the onScaleChanged callback', (WidgetTester tester) async {
      ImageProvider? imageProvider;

      double lastScale = 1.0;
      
      await tester.runAsync(() async {
        imageProvider = await createColorImage(Colors.green);
      });
      
      Widget testWidget = MediaQuery(
        data: const MediaQueryData(size: Size(600, 800)),
        child: EasyImageView(
          imageProvider: imageProvider!,
          minScale: 0.5,
          maxScale: 6.0,
          onScaleChanged: (scale) {
            lastScale = scale;
          })
      );

      await tester.pumpWidget(testWidget);

      // Create the finder
      final interactiveViewFinder = find.byType(InteractiveViewer);

      // Get the center      
      final center = tester.getCenter(interactiveViewFinder);
    
      // Zoom in:
      final Offset scaleStart1 = center;
      final Offset scaleStart2 = Offset(center.dx + 10.0, center.dy);
      final Offset scaleEnd1 = Offset(center.dx - 10.0, center.dy);
      final Offset scaleEnd2 = Offset(center.dx + 10.0, center.dy);
      final TestGesture gesture = await tester.createGesture();
      final TestGesture gesture2 = await tester.createGesture();
      await gesture.down(scaleStart1);
      await gesture2.down(scaleStart2);
      await tester.pump();
      await gesture.moveTo(scaleEnd1);
      await gesture2.moveTo(scaleEnd2);
      await tester.pump();
      await gesture.up();
      await gesture2.up();
      await tester.pumpAndSettle();

      expect(lastScale, 2.0);
    });
  });
}
